function plot_clouds (X, varargin)

% PLOT_CLOUDS   Plots the point clouds corresponding to the given 2d or 3d
%               samples whose first component mark their corresponding class.
%
%   PLOT_CLOUDS(X, STYLE='x', [COLOR]) determines the number of classes by
%   counting the number of different  entries in the first column of X and
%   plots the each class with a different color and if given a different
%   style. If the colors are given as well then they are used. Otherwise a
%   default colorscheme is used. If there are less colors or styles than
%   classes an error is thrown.
%
%   The samples can be 2- or 3-dimensional the appropriate plotting routine
%   is automatically chosen.
%
%
% created: 2004 12 15 - Simon Meier

    % determine params
    n = size(X,1);
    d = size(X,2) - 1;
    
    % count classes
    Y = sort(X(:,1));
    m = 1;
    C = [Y(1)];
    for k=2:n
        if (Y(k-1) ~= Y(k))
            m = m + 1;
            C = [C; Y(k)];
        end
    end;
    
    % set default values or check varargins
    if (d == 2)
        plot_fun = @plot_samples2d;
    elseif (d == 3)
        plot_fun = @plot_samples3d;
    else
        error('only 2d and 3d plots can be made!');
    end;
    
    styles = 'x';
    if (nargin >= 2)
        styles = varargin{1};
    end;
    styles = repmat(styles,1,m);
    
    if (nargin >= 3)
        colors = varargin{2}; 
    else
        colors = [1 0 0; 0 0 1; 0 1 0; 1 1 0; 1 0 1; 0 1 1];
    end;
    if (size(colors,1) < m)
        error('too few colors specified or default colors taken with more than 6 classes!');
    end;
    
    % save hold on state
    old_hold = ishold;
    
    % plot all classes
    hold on;
    for k=1:m
        Y = X(find(X(:,1)==C(k)), 2:d+1);
        feval(plot_fun, Y, styles(k), colors(k,:));
    end;
    if (not(old_hold))
        hold off;
    end;
    