function plot_line(w, length, varargin)

% PLOT_LINE         Plots a a line given by its normal vector in homogeneus
%                   coordinates.
%
%   W ist given in homogeneus coordinates. Therefore W = [B N] where B is a
%   scalar representing the distance to the origin in units with length
%   norm(N,2) and N is the normal vector.
%
%   PLOT_LINE(W, LENGTH) plots the line given by N'*x + B = 0 with default
%   style '-k' where the length specifies the length of the line.
%
%   PLOT_LINE(W, LENGTH, STYLE) plots the line given by N'*x + B = 0 with default
%   style STYLE where the length specifies the length of the line.
%
%   PLOT_LINE(W, LENGTH, STYLE, COLOR) plots the line given by N'*x + B = 0 with default
%   style STYLE and color COLOR (see ColorSpec) where the length specifies the length of the
%   line. The color given in STYLE will be overriden.
%
%
% created: 2004 12 15 - Simon Meier

    % flip w if its not a column vector
    if (size(w,1) == 1)
        w = w';
    end;

    % the conditions of a satisfying point
    A = [w'; [1 zeros(1, size(w, 1)-1)]];
    
    % the distance of the affine hyperplane we're looking for
    x0 = A \ [0; 1];
    
    % the homogeneus solution of the affine plane
    A0 = null(A);
    
    % our parameter vector
    t = length*[-0.5 0.5]';
    
    % calculate the transformed points
    y = A0*t';
    y = y + repmat(x0,1,size(y,2));
    ys = y(2:size(y,1),:);

    % and plot them using the specified settings
    style = '-g';
    if (nargin >= 3)
        style = varargin{1};
    end
    if (nargin >= 4)
        plot(ys(1,:),ys(2,:),style,'color',varargin{2});
    else
        plot(ys(1,:),ys(2,:),style);
    end
